
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

## This concern has +like+, +unlike+ controller actions
## When you use it, be sure that +set_sociable+ method is implemented in your controller, otherwise an fatal error will raise.
module SociableController
  extend ActiveSupport::Concern

  VIEWABLE_METHODS = [:show]

  included do
    before_action :authenticate_user!, only: [:like]
    before_action :authorize_sociable!, only: [:like]
    before_action :view_object!, only: VIEWABLE_METHODS
  end

  # PUT /v1/learning_objects/1/like
  # PUT /v1/learning_objects/1/like.json
  def like
    if !sociable.liked? current_user
      sociable.like current_user
      render json: {count: sociable.likes.count}, status: :created
    elsif sociable.liked? current_user
      sociable.dislike current_user
      render json: {count: sociable.likes.count}, status: :ok
    else
      render status: :forbidden
    end
  end

  protected

  def authorize_sociable!
    authorize sociable
  end

  def sociable
    raise NotImplementedError
  end

  def view_object!
    sociable.view current_user if user_signed_in?
  end

end
