
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::ActivitiesController < ApplicationController
  include ::ResourceModel
  include ::Paginator
  before_action :authenticate_user!

  # GET v1/activities
  # GET v1/activities.json
  # Render all activities that logged user can see
  def index
    authorize :activity, :index?
    activities = paginate ::ActivityPolicy::Scope.new(current_user, ::PublicActivity::Activity).resolve
    render json: activities
  end

  # GET v1/users/1/activities
  # GET v1/users/1/activities.json
  # Render specific user activities
  # Only followers can see user activities
  def user_activities
    raise ::Pundit::NotAuthorizedError unless ::ActivityPolicy.new(current_user, resource_model).user_activities?
    activities = paginate resource_model.activities_filtered
    render json: activities
  end

  def me
    authorize :activity, :index?
    activities = paginate current_user.activities_filtered
    render json: activities
  end
end
